diff --git a/modules/image/Image_gan/style_transfer/lapstyle_ocean/module.py b/modules/image/Image_gan/style_transfer/lapstyle_ocean/module.py
index 8125b9ec3618caca1026403f71fb2c16846a1e5d..ea82448cd63a582da123bbeee69b83bab6aaec3d 100644
--- a/modules/image/Image_gan/style_transfer/lapstyle_ocean/module.py
+++ b/modules/image/Image_gan/style_transfer/lapstyle_ocean/module.py
@@ -44,11 +44,11 @@ class Lapstyle_ocean:
self.network = LapStylePredictor(weight_path=self.pretrained_model)
def style_transfer(self,
- images=None,
- paths=None,
- output_dir='./transfer_result/',
- use_gpu=False,
- visualization=True):
+ images: list = None,
+ paths: list = None,
+ output_dir: str = './transfer_result/',
+ use_gpu: bool = False,
+ visualization: bool = True):
'''
Transfer a image to ocean style.
@@ -59,9 +59,9 @@ class Lapstyle_ocean:
- content (str): path to input image;
- style (str) : path to style image;
- output_dir: the dir to save the results
- use_gpu: if True, use gpu to perform the computation, otherwise cpu.
- visualization: if True, save results in output_dir.
+ output_dir (str): the dir to save the results
+ use_gpu (bool): if True, use gpu to perform the computation, otherwise cpu.
+ visualization (bool): if True, save results in output_dir.
'''
results = []
paddle.disable_static()